import requests

from automon.log import Logging
from .config import RequestsConfig


class RequestsClient(object):
    def __init__(self, url: str = None, data: dict = None, headers: dict = None,
                 config: RequestsConfig = None):
        """Wrapper for requests library"""

        self._log = Logging(name=RequestsClient.__name__, level=Logging.DEBUG)

        self.config = config or RequestsConfig()

        self.url = url
        self.data = data
        self.headers = headers
        self.results = None
        self.requests = requests

        if url:
            self.url = url
            self.results = self.get(url=self.url, data=self.data, headers=self.headers)

    def get(self,
            url: str = None,
            data: dict = None,
            headers: dict = None, **kwargs) -> bool:
        """requests.get"""

        try:
            self.results = requests.get(url=url, data=data, headers=headers, **kwargs)
            self._log.debug(f'{self.results.status_code} '
                            f'{self.results.url} '
                            f'{round(len(self.results.content) / 1024, 2)}  KB')
            return True
        except Exception as e:
            self._log.error(f'{self.results.status_code} get failed. {e}', enable_traceback=False)
        return False

    def post(self,
             url: str = None,
             data: dict = None,
             headers: dict = None, **kwargs) -> bool:
        """requests.post"""

        try:
            self.results = requests.post(url=url, data=data, headers=headers, **kwargs)
            self._log.debug(f'{self.results.status_code} '
                            f'{self.results.url} '
                            f'{round(len(self.results.content) / 1024, 2)}  KB')
            return True
        except Exception as e:
            self._log.error(f'{self.results.status_code} post failed. {e}', raise_exception=False)
        return False


class Requests(RequestsClient):
    pass



import os
import urllib3

from automon.log import Logging


class MinioConfig(object):

    def __init__(self, endpoint: str = None,
                 access_key: str = None,
                 secret_key: str = None,
                 session_token: str = None,
                 secure: bool = None,
                 region: str = None,
                 http_client: urllib3.PoolManager = None):
        """Minio config
        """
        self._log = Logging(name=MinioConfig.__name__, level=Logging.ERROR)

        self.endpoint = endpoint or os.getenv('MINIO_ENDPOINT') or 'localhost'
        self.access_key = access_key or os.getenv('MINIO_ACCESS_KEY')
        self.secret_key = secret_key or os.getenv('MINIO_SECRET_KEY')
        self.session_token = session_token or os.getenv('MINIO_SESSION_TOKEN')
        self.secure = secure or os.getenv('MINIO_SECURE') or True
        self.region = region or os.getenv('MINIO_REGION')
        self.http_client = http_client or os.getenv('MINIO_HTTP_CLIENT')

        if not self.endpoint:
            self._log.warn(f'missing MINIO_ENDPOINT')

        if not self.access_key:
            self._log.warn(f'missing MINIO_ACCESS_KEY')

        if not self.secret_key:
            self._log.warn(f'missing MINIO_SECRET_KEY')

    def isConfigured(self):
        if self.endpoint and self.access_key and self.secret_key:
            return True
        return False

    def __repr__(self):
        return f'{self.endpoint} {self.region}'
